# vim: tabstop=4 shiftwidth=4 softtabstop=4

# Copyright 2011 Justin Santa Barbara
# All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

import unittest

from nova import flags
from nova.tests.integrated import integrated_helpers


FLAGS = flags.FLAGS
FLAGS.verbose = True


class KeysTest(unittest.TestCase):
    def setUp(self):
        context = integrated_helpers.IntegratedUnitTestContext.startup()
        self.api = context.get_openstack_api()

    def tearDown(self):
        integrated_helpers.IntegratedUnitTestContext.shutdown()

    def test_get_keys(self):
        """Simple check that listing keys works"""
        keys = self.api.get_keys_detail()
        for key in keys:
            print("key: %s" % key)

    def _find_key(self, key_name):
        """Return key with specified name or None if not found"""
        keys = self.api.get_keys_detail()
        for key in keys:
            if key['name'] == key_name:
                return key
        return None

    def test_create_and_delete_key(self):
        """Creates and deletes a key"""

        # Find unused key name
        keys = self.api.get_keys_detail()
        key_names = [key.name for key in keys]
        key_name = integrated_helpers.generate_new_element(key_names,
                                                           'unittest_')

        # Create key with name
        created_key = self.api.post_key({'key': {'name': key_name}})
        print "created_key: %s" % created_key
        private_key = created_key['privateKey']
        print "private_key: %s" % private_key
        self.assertTrue(private_key)
        self.assertTrue('BEGIN RSA PRIVATE KEY' in private_key)

        # Check it's there
        found_key = self._find_key(key_name)
        self.assertEqual(key_name, found_key['name'])

        # Delete the key
        self.api.delete_key(created_key['id'])

        # Check it's not there any more
        found_key = self._find_key(key_name)
        self.assertFalse(found_key)


if __name__ == "__main__":
    unittest.main()
